@@ -811,16 +811,14 @@ sub setup ($) {
 	    TYPE => 'HASH:ARRAY:STRING',
 	    VARNAME => 'crossbuild_core_depends',
 	    GROUP => 'Multiarch support (transitional)',
-	    DEFAULT => { arm64 => ['crossbuild-essential-arm64:native'],
-			 armel => ['crossbuild-essential-armel:native'],
-			 armhf => ['crossbuild-essential-armhf:native'],
-			 ia64 => ['crossbuild-essential-ia64:native'],
-			 mips => ['crossbuild-essential-mips:native'],
-			 mipsel => ['crossbuild-essential-mipsel:native'],
-			 powerpc => ['crossbuild-essential-powerpc:native'],
-			 sparc => ['crossbuild-essential-sparc:native']
-	    	       },
-	    HELP => 'Per-architecture dependencies required for cross-building.'
+	    DEFAULT => {},
+	    HELP => 'Per-architecture dependencies required for cross-building. By default, if a Debian architecture is not found as a key in this hash, the package crossbuild-essential-${hostarch}:native will be installed.',
+	    EXAMPLE => '
+$crossbuild_core_depends = {
+    nios2 => [\'crossbuild-essential-nios2:native\', \'special-package\'],
+    musl-linux-mips => [\'crossbuild-essential-musl-linux-mips:native\', \'super-special\'],
+}
+'
 	},	'BUILD_SOURCE'				=> {
 	    TYPE => 'BOOL',
 	    VARNAME => 'build_source',
@@ -894,6 +892,13 @@ sub setup ($) {
 	    },
 	    HELP => 'Build dependency resolver.  The \'apt\' resolver is currently the default, and recommended for most users.  This resolver uses apt-get to resolve dependencies.  Alternative resolvers are \'apt\', \'aptitude\' and \'aspcud\'. The \'apt\' resolver uses a built-in resolver module while the \'aptitude\' resolver uses aptitude to resolve build dependencies.  The aptitude resolver is similar to apt, but is useful in more complex situations, such as where multiple distributions are required, for example when building from experimental, where packages are needed from both unstable and experimental, but defaulting to unstable. If the dependency situation is too complex for either apt or aptitude to solve it, you can use the \'aspcud\' resolver which is a real SAT solver and will thus alwyas find a solution if a solution exists.'
 	},
+	'CLEAN_SOURCE'				=> {
+	    TYPE => 'BOOL',
+	    VARNAME => 'clean_source',
+	    GROUP => 'Build options',
+	    DEFAULT => 1,
+	    HELP => 'When running sbuild from within an unpacked source tree, run the \'clean\' target before generating the source package. This might require some of the build dependencies necessary for running the \'clean\' target to be installed on the host machine. Only disable if you start from a clean checkout and you know what you are doing.'
+	},
 	'LINTIAN'				=> {
 	    TYPE => 'STRING',
 	    VARNAME => 'lintian',
